@@ -61,7 +61,7 @@ Try one of the following:
     `isort . --check --diff` - Check to see if imports are correctly sorted within this project.
     `isort --help` - In-depth information about isort's available command-line options.
 
-Visit https://timothycrosley.github.io/isort/ for complete information about how to use isort.
+Visit https://pycqa.github.io/isort/ for complete information about how to use isort.
 """
 
 
@@ -115,17 +115,16 @@ def iter_source_code(paths: Iterable[str], config: Config, skipped: List[str]) -
                 base_path = Path(dirpath)
                 for dirname in list(dirnames):
                     full_path = base_path / dirname
+                    resolved_path = full_path.resolve()
                     if config.is_skipped(full_path):
                         skipped.append(dirname)
                         dirnames.remove(dirname)
-
-                    resolved_path = full_path.resolve()
-                    if resolved_path in visited_dirs:  # pragma: no cover
-                        if not config.quiet:
-                            warn(f"Likely recursive symlink detected to {resolved_path}")
-                        dirnames.remove(dirname)
                     else:
-                        visited_dirs.add(resolved_path)
+                        if resolved_path in visited_dirs:  # pragma: no cover
+                            if not config.quiet:
+                                warn(f"Likely recursive symlink detected to {resolved_path}")
+                            dirnames.remove(dirname)
+                    visited_dirs.add(resolved_path)
 
                 for filename in filenames:
                     filepath = os.path.join(dirpath, filename)
@@ -145,9 +144,9 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "start guide, otherwise, one or more files/directories/stdin must be provided. "
         "Use `-` as the first argument to represent stdin. Use --interactive to use the pre 5.0.0 "
         "interactive behavior."
-        ""
+        " "
         "If you've used isort 4 but are new to isort 5, see the upgrading guide:"
-        "https://timothycrosley.github.io/isort/docs/upgrade_guides/5.0.0/."
+        "https://pycqa.github.io/isort/docs/upgrade_guides/5.0.0/."
     )
     inline_args_group = parser.add_mutually_exclusive_group()
     parser.add_argument(
@@ -156,7 +155,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="src_paths",
         action="append",
         help="Add an explicitly defined source path "
-        "(modules within src paths have their imports automatically catorgorized as first_party).",
+        "(modules within src paths have their imports automatically categorized as first_party).",
     )
     parser.add_argument(
         "-a",
@@ -587,9 +586,9 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         action="store",
         dest="py_version",
         choices=tuple(VALID_PY_TARGETS) + ("auto",),
-        help="Tells isort to set the known standard library based on the the specified Python "
+        help="Tells isort to set the known standard library based on the specified Python "
         "version. Default is to assume any Python 3 version could be the target, and use a union "
-        "off all stdlib modules across versions. If auto is specified, the version of the "
+        "of all stdlib modules across versions. If auto is specified, the version of the "
         "interpreter used to run isort "
         f"(currently: {sys.version_info.major}{sys.version_info.minor}) will be used.",
     )
@@ -824,11 +823,10 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
         print(json.dumps(config.__dict__, indent=4, separators=(",", ": "), default=_preconvert))
         return
     elif file_names == ["-"]:
-        arguments.setdefault("settings_path", os.getcwd())
         api.sort_stream(
             input_stream=sys.stdin if stdin is None else stdin,
             output_stream=sys.stdout,
-            **arguments,
+            config=config,
         )
     else:
         skipped: List[str] = []
@@ -909,7 +907,7 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
             )
         warn(
             "W0500: Please see the 5.0.0 Upgrade guide: "
-            "https://timothycrosley.github.io/isort/docs/upgrade_guides/5.0.0/"
+            "https://pycqa.github.io/isort/docs/upgrade_guides/5.0.0/"
         )
 
     if wrong_sorted_files:
