@@ -329,7 +329,7 @@ class Config(_Config):
                             f"Can't set both {key} and {section_name} in the same config file.\n"
                             f"Default to {section_name} if unsure."
                             "\n\n"
-                            "See: https://timothycrosley.github.io/isort/"
+                            "See: https://pycqa.github.io/isort/"
                             "#custom-sections-and-ordering."
                         )
                     else:
@@ -344,7 +344,7 @@ class Config(_Config):
                             f"`{key}` setting is defined, but {maps_to_section} is not"
                             " included in `sections` config option:"
                             f" {combined_config.get('sections', SECTION_DEFAULTS)}.\n\n"
-                            "See: https://timothycrosley.github.io/isort/"
+                            "See: https://pycqa.github.io/isort/"
                             "#custom-sections-and-ordering."
                         )
             if key.startswith(IMPORT_HEADING_PREFIX):
@@ -498,12 +498,13 @@ class Config(_Config):
             return self._known_patterns
 
         self._known_patterns = []
-        for placement in reversed(self.sections):
+        pattern_sections = [STDLIB] + [section for section in self.sections if section != STDLIB]
+        for placement in reversed(pattern_sections):
             known_placement = KNOWN_SECTION_MAPPING.get(placement, placement).lower()
             config_key = f"{KNOWN_PREFIX}{known_placement}"
             known_modules = getattr(self, config_key, self.known_other.get(known_placement, ()))
             extra_modules = getattr(self, f"extra_{known_placement}", ())
-            all_modules = set(known_modules).union(extra_modules)
+            all_modules = set(extra_modules).union(known_modules)
             known_patterns = [
                 pattern
                 for known_pattern in all_modules
